@@ -3,11 +3,12 @@ TXS 0506+056, as described in https://arxiv.org/abs/1807.08794.
 """
 from flarestack.core.unblinding import create_unblinder
 from flarestack.data.icecube import txs_sample_v1, ps_v003_p02, nt_v002_p05
-from flarestack.analyses.txs_0506_056.make_txs_catalogue import txs_cat_path,\
-    txs_catalogue
+from flarestack.analyses.txs_0506_056.make_txs_catalogue import (
+    txs_cat_path,
+    txs_catalogue,
+)
 from flarestack.utils.custom_dataset import custom_dataset
-from flarestack.analyses.txs_0506_056.load_gao_spectral_models import \
-    spline_name
+from flarestack.analyses.txs_0506_056.load_gao_spectral_models import spline_name
 
 # Initialise Injectors/LLHs
 
@@ -16,7 +17,7 @@ from flarestack.analyses.txs_0506_056.load_gao_spectral_models import \
 llh_time = {
     "time_pdf_name": "fixed_ref_box",
     "fixed_ref_time_mjd": 56937.81,
-    "pre_window": 0.,
+    "pre_window": 0.0,
     "post_window": 57096.22 - 56937.81,
 }
 #
@@ -42,8 +43,9 @@ name = "analyses/benchmarks/TXS_0506+056/"
 unblind_dict = {
     "name": name,
     "mh_name": "fixed_weights",
-    "dataset": custom_dataset(ps_v003_p02, txs_catalogue,
-                               unblind_llh["llh_sig_time_pdf"]),
+    "dataset": custom_dataset(
+        ps_v003_p02, txs_catalogue, unblind_llh["llh_sig_time_pdf"]
+    ),
     # "dataset": txs_sample_v1.get_seasons(""),
     "catalogue": txs_cat_path,
     "llh_dict": unblind_llh,
