@@ -6,9 +6,19 @@ from flarestack.core.experimental_results import ExperimentalResultHandler
 from flarestack.data.icecube import ps_v002_p01, ps_v002_p03
 from flarestack.shared import plot_output_dir, flux_to_k
 from flarestack.icecube_utils.reference_sensitivity import reference_sensitivity
-from flarestack.analyses.ccsn.stasik_2017.ccsn_limits import limits, get_figure_limits, p_vals
-from flarestack.analyses.ccsn.necker_2019.ccsn_helpers import sn_cats, updated_sn_catalogue_name, \
-    sn_time_pdfs, raw_output_dir, pdf_names, limit_sens
+from flarestack.analyses.ccsn.stasik_2017.ccsn_limits import (
+    limits,
+    get_figure_limits,
+    p_vals,
+)
+from flarestack.analyses.ccsn.necker_2019.ccsn_helpers import (
+    sn_cats,
+    updated_sn_catalogue_name,
+    sn_time_pdfs,
+    raw_output_dir,
+    pdf_names,
+    limit_sens,
+)
 from flarestack.core.time_pdf import TimePDF
 from flarestack.analyses.ccsn import get_sn_color
 from flarestack.cluster import analyse
@@ -16,6 +26,7 @@ from flarestack.cluster.run_desy_cluster import wait_for_cluster
 import math
 import pickle
 import matplotlib
+
 # matplotlib.use('Agg')
 import matplotlib.pyplot as plt
 from flarestack.utils.custom_dataset import custom_dataset
@@ -28,8 +39,8 @@ import time
 start = time.time()
 
 logging.getLogger().setLevel("DEBUG")
-logging.debug('logging level is DEBUG')
-logging.getLogger('matplotlib').setLevel('INFO')
+logging.debug("logging level is DEBUG")
+logging.getLogger("matplotlib").setLevel("INFO")
 
 # LLH Energy PDF
 llh_energy = {
@@ -42,10 +53,10 @@ cluster = 500
 gammas = [2, 2.5]
 
 # minimizer to use
-mh_name = 'fit_weights'
+mh_name = "fit_weights"
 
 # using the decay pdfs
-pdf_type = 'decay'
+pdf_type = "decay"
 
 # Base name
 raw = raw_output_dir + f"/calculate_sensitivity_ps-v002p03/{mh_name}/{pdf_type}/"
@@ -56,12 +67,12 @@ full_res = dict()
 # set up empty list to store cluster job IDs in
 job_ids = []
 
-plot_results = '_figureresults'
+plot_results = "_figureresults"
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     # loop over IIP and IIn SN catalogues
-    for cat in ['IIP', 'IIn']:
+    for cat in ["IIP", "IIn"]:
 
         name = raw + cat + "/"
 
@@ -76,19 +87,19 @@ if __name__ == '__main__':
             # set up an empty results array for this time pdf
             time_res = dict()
 
-            logging.debug(f'time_pdf is {llh_time}')
+            logging.debug(f"time_pdf is {llh_time}")
 
-            time_key = str(llh_time['decay_time'])
+            time_key = str(llh_time["decay_time"])
 
-            pdf_time = llh_time['decay_time'] / 364.25
+            pdf_time = llh_time["decay_time"] / 364.25
             pdf_name = pdf_names(pdf_type, pdf_time)
             cat_path = updated_sn_catalogue_name(cat)  # , pdf_name=pdf_name)
-            logging.debug('catalogue path: ' + str(cat_path))
+            logging.debug("catalogue path: " + str(cat_path))
 
             # load catalogue and select the closest source
             # that serves for estimating a good injection scale later
             catalogue = np.load(cat_path)
-            logging.debug('catalogue dtype: ' + str(catalogue.dtype))
+            logging.debug("catalogue dtype: " + str(catalogue.dtype))
             closest_src = np.sort(catalogue, order="distance_mpc")[0]
 
             time_name = name + time_key + "/"
@@ -98,9 +109,7 @@ if __name__ == '__main__':
                 "llh_name": "standard",
                 "llh_energy_pdf": llh_energy,
                 "llh_sig_time_pdf": llh_time,
-                "llh_bkg_time_pdf": {
-                    "time_pdf_name": "steady"
-                }
+                "llh_bkg_time_pdf": {"time_pdf_name": "steady"},
             }
 
             # set up an injection dictionary which will be equal to the time pdf dictionary
@@ -115,19 +124,30 @@ if __name__ == '__main__':
 
                 # try to estimate a good scale based on the sensitivity from the 7-yr PS sensitivity
                 # at the declination of the closest source
-                scale = 0.00025 * (flux_to_k(reference_sensitivity(
-                    np.sin(closest_src["dec_rad"]), gamma=gamma
-                ) * 40 * math.sqrt(float(len(catalogue)))) * 200.) / length
+                scale = (
+                    0.00025
+                    * (
+                        flux_to_k(
+                            reference_sensitivity(
+                                np.sin(closest_src["dec_rad"]), gamma=gamma
+                            )
+                            * 40
+                            * math.sqrt(float(len(catalogue)))
+                        )
+                        * 200.0
+                    )
+                    / length
+                )
 
                 # in some cases the sensitivity is outside the tested range
                 # to get a good sensitivity, adjust the scale in these cases
-                if (gamma == 2.5) and (cat == 'IIn'):
+                if (gamma == 2.5) and (cat == "IIn"):
                     scale *= 1.8
-                if (gamma == 2.5) and (cat == 'IIP'):
+                if (gamma == 2.5) and (cat == "IIP"):
                     scale *= 0.15
-                if (gamma == 2.0) and (cat == 'IIP'):
+                if (gamma == 2.0) and (cat == "IIP"):
                     scale *= 0.5
-                if cat == 'IIn':
+                if cat == "IIn":
                     scale *= 5
                 if length > 700:
                     scale *= 2
@@ -146,23 +166,26 @@ if __name__ == '__main__':
                 mh_dict = {
                     "name": full_name,
                     "mh_name": mh_name,
-                    "dataset": custom_dataset(ps_v002_p03, catalogue,
-                                              llh_dict["llh_sig_time_pdf"]),
+                    "dataset": custom_dataset(
+                        ps_v002_p03, catalogue, llh_dict["llh_sig_time_pdf"]
+                    ),
                     "catalogue": cat_path,
                     "inj_dict": inj_dict,
                     "llh_dict": llh_dict,
                     "scale": scale,
-                    "n_trials": 100/cluster if cluster else 100,
-                    "n_steps": 10
+                    "n_trials": 100 / cluster if cluster else 100,
+                    "n_steps": 10,
                 }
 
                 # call the main analyse function
                 job_id = None
-                job_id = analyse(mh_dict,
-                                 cluster=True if cluster else False,
-                                 n_cpu=1 if cluster else 32,
-                                 n_jobs=cluster,
-                                 h_cpu='01:59:59')
+                job_id = analyse(
+                    mh_dict,
+                    cluster=True if cluster else False,
+                    n_cpu=1 if cluster else 32,
+                    n_jobs=cluster,
+                    h_cpu="01:59:59",
+                )
                 job_ids.append(job_id)
 
                 time_res[gamma] = mh_dict
@@ -173,7 +196,7 @@ if __name__ == '__main__':
 
     # Wait for cluster. If there are no cluster jobs, this just runs
     if cluster and np.any(job_ids):
-        logging.info(f'waiting for jobs {job_ids}')
+        logging.info(f"waiting for jobs {job_ids}")
         wait_for_cluster(job_ids)
 
     # set up an empty results dictionary
@@ -201,16 +224,24 @@ if __name__ == '__main__':
             # Loop over gamma
             for (gamma, rh_dict) in sorted(time_res.items()):
 
-                logging.debug(f'gamma is {gamma}, cat is {cat_name}, pdf time is {time_key}')
+                logging.debug(
+                    f"gamma is {gamma}, cat is {cat_name}, pdf time is {time_key}"
+                )
                 # calling ResultsHandler will calculate the overfluctuations and sensitivities
                 rh = ResultsHandler(rh_dict)
 
                 # get the injection time in seconds
-                inj_time = rh_dict["inj_dict"]["injection_sig_time_pdf"]["decay_length"] * 60 * 60 * 24
+                inj_time = (
+                    rh_dict["inj_dict"]["injection_sig_time_pdf"]["decay_length"]
+                    * 60
+                    * 60
+                    * 24
+                )
 
                 # Convert IceCube numbers to astrophysical quantities
                 astro_sens, astro_disc = rh.astro_values(
-                    rh_dict["inj_dict"]["injection_energy_pdf"])
+                    rh_dict["inj_dict"]["injection_energy_pdf"]
+                )
 
                 key = "Energy Flux (GeV cm^{-2} s^{-1})"
 
@@ -227,17 +258,18 @@ if __name__ == '__main__':
                 stacked_sens_flux[cat_name][time_key][gamma] = (
                     rh.sensitivity,
                     rh.sensitivity_err,
-                    astro_sens[e_key] * inj_time
+                    astro_sens[e_key] * inj_time,
                 )
 
             name = "{0}/{1}/{2}".format(raw, cat_name, time_key)
 
             # make plots total energy/fluence plots
-            for j, [fluence, energy] in enumerate([[sens_livetime, sens_e],
-                                                  [disc_pots_livetime, disc_e]]):
+            for j, [fluence, energy] in enumerate(
+                [[sens_livetime, sens_e], [disc_pots_livetime, disc_e]]
+            ):
 
-                logging.debug('fluence: ' + str(fluence))
-                logging.debug('energy: ' + str(energy))
+                logging.debug("fluence: " + str(fluence))
+                logging.debug("energy: " + str(energy))
 
                 plt.figure()
                 ax1 = plt.subplot(111)
@@ -247,15 +279,24 @@ if __name__ == '__main__':
                 # cols = ["#00A6EB", "#F79646", "g", "r"]
                 linestyle = ["-", "-"][j]
 
-                ax1.plot(fracs, fluence, label=labels, linestyle=linestyle,
-                         )
-                ax2.plot(fracs, energy, linestyle=linestyle,
-                         )
+                ax1.plot(
+                    fracs,
+                    fluence,
+                    label=labels,
+                    linestyle=linestyle,
+                )
+                ax2.plot(
+                    fracs,
+                    energy,
+                    linestyle=linestyle,
+                )
 
-                y_label = [r"Energy Flux (GeV cm^{-2} s^{-1})",
-                           r"Mean Isotropic-Equivalent $E_{\nu}$ (erg)"]
+                y_label = [
+                    r"Energy Flux (GeV cm^{-2} s^{-1})",
+                    r"Mean Isotropic-Equivalent $E_{\nu}$ (erg)",
+                ]
 
-                ax2.grid(True, which='both')
+                ax2.grid(True, which="both")
                 ax1.set_ylabel(r"Total Fluence [GeV cm$^{-2}$]", fontsize=12)
                 ax2.set_ylabel(r"Mean Isotropic-Equivalent $E_{\nu}$ (erg)")
                 ax1.set_xlabel(r"Spectral Index ($\gamma$)")
@@ -264,22 +305,33 @@ if __name__ == '__main__':
 
                 for k, ax in enumerate([ax1, ax2]):
                     y = [fluence, energy][k]
-                    logging.debug('y: ' + str(y))
+                    logging.debug("y: " + str(y))
 
                     # ax.set_ylim(0.95 * min(y),
                     #             1.1 * max(y))
 
-                plt.title("Stacked " + ["Sensitivity", "Discovery Potential"][j] +
-                          " for " + cat_name + " SNe")
+                plt.title(
+                    "Stacked "
+                    + ["Sensitivity", "Discovery Potential"][j]
+                    + " for "
+                    + cat_name
+                    + " SNe"
+                )
 
                 plt.tight_layout()
-                plt.savefig(plot_output_dir(name) + "/spectral_index_" +
-                            ["sens", "disc"][j] + "_" + cat_name + ".pdf")
+                plt.savefig(
+                    plot_output_dir(name)
+                    + "/spectral_index_"
+                    + ["sens", "disc"][j]
+                    + "_"
+                    + cat_name
+                    + ".pdf"
+                )
                 plt.close()
 
     # ================================       save sensitivities        ============================== #
 
-    with open(limit_sens(raw), 'wb') as f:
+    with open(limit_sens(raw), "wb") as f:
         pickle.dump(stacked_sens_flux, f)
 
     # =================================        make final plots       =============================== #
@@ -299,28 +351,45 @@ if __name__ == '__main__':
             y = [stacked_sens_flux[cat_name][key][gamma][0] for key in cat_dict.keys()]
             y = np.array(y)[np.argsort(x_raw)]
 
-            yerr = [stacked_sens_flux[cat_name][key][gamma][1] for key in cat_dict.keys()]
+            yerr = [
+                stacked_sens_flux[cat_name][key][gamma][1] for key in cat_dict.keys()
+            ]
             yerr = np.array(yerr)[np.argsort(x_raw)]
 
-            logging.debug('\n x: {0};      y: {1};       yerr: {2}'.format(x, y, yerr))
+            logging.debug("\n x: {0};      y: {1};       yerr: {2}".format(x, y, yerr))
 
-            flux_ax.errorbar(x, y, yerr=np.array(yerr).T,
-                             ls='--', label=cat_name, marker='', color=get_sn_color(cat_name))
+            flux_ax.errorbar(
+                x,
+                y,
+                yerr=np.array(yerr).T,
+                ls="--",
+                label=cat_name,
+                marker="",
+                color=get_sn_color(cat_name),
+            )
 
-        flux_ax.set_xscale('log')
-        flux_ax.set_yscale('log')
-        flux_ax.set_xlabel(r'$t_{\mathrm{decay}}$ in years')
-        flux_ax.set_ylabel(r'flux in GeV$^{-1}$ s$^{-1}$ cm$^{-2}$')
+        flux_ax.set_xscale("log")
+        flux_ax.set_yscale("log")
+        flux_ax.set_xlabel(r"$t_{\mathrm{decay}}$ in years")
+        flux_ax.set_ylabel(r"flux in GeV$^{-1}$ s$^{-1}$ cm$^{-2}$")
         flux_ax.legend()
 
-        fname_flux = plot_output_dir(raw + f'stacked_sensitivity_flux_gamma{gamma}_{mh_name}.pdf')
-        logging.debug(f'saving figure under {fname_flux}')
+        fname_flux = plot_output_dir(
+            raw + f"stacked_sensitivity_flux_gamma{gamma}_{mh_name}.pdf"
+        )
+        logging.debug(f"saving figure under {fname_flux}")
         flux_fig.savefig(fname_flux)
 
         stacked_sens = {
             cat_name: np.array(
-                [(stacked_sens_flux[cat_name][time_key][gamma][2], float(time_key) / 364.25)
-                 for time_key in stacked_sens_flux[cat_name]], dtype='<f8'
+                [
+                    (
+                        stacked_sens_flux[cat_name][time_key][gamma][2],
+                        float(time_key) / 364.25,
+                    )
+                    for time_key in stacked_sens_flux[cat_name]
+                ],
+                dtype="<f8",
             )
             for cat_name in stacked_sens_flux
         }
@@ -330,54 +399,95 @@ if __name__ == '__main__':
 
         # loop over SN catalogues and plot the total emitted neutrino energy against the decay length
         for cat_name in stacked_sens:
-            plot_arr = np.array(stacked_sens[cat_name], dtype='<f8')
-            logging.debug(f'plot array: \n {plot_arr}')
+            plot_arr = np.array(stacked_sens[cat_name], dtype="<f8")
+            logging.debug(f"plot array: \n {plot_arr}")
 
-            yerr = plot_arr[:,0]*0.1
-            patch = ax.errorbar(plot_arr[:,1], plot_arr[:,0], xerr=plot_arr[:,1]*0.05,
-                                yerr=yerr, uplims=True, ls='', markersize=1, capsize=0.5, color=get_sn_color(cat_name))
+            yerr = plot_arr[:, 0] * 0.1
+            patch = ax.errorbar(
+                plot_arr[:, 1],
+                plot_arr[:, 0],
+                xerr=plot_arr[:, 1] * 0.05,
+                yerr=yerr,
+                uplims=True,
+                ls="",
+                markersize=1,
+                capsize=0.5,
+                color=get_sn_color(cat_name),
+            )
 
-            ax.plot(plot_arr[:,1], plot_arr[:,0] - yerr, marker='v', color=patch.lines[0].get_c(),
-                    label=cat_name, ls='')
+            ax.plot(
+                plot_arr[:, 1],
+                plot_arr[:, 0] - yerr,
+                marker="v",
+                color=patch.lines[0].get_c(),
+                label=cat_name,
+                ls="",
+            )
 
-            pval_mask = p_vals[pdf_type][cat_name if not 'P' in cat_name else 'IIp']['pval'] >= 0.5
+            pval_mask = (
+                p_vals[pdf_type][cat_name if not "P" in cat_name else "IIp"]["pval"]
+                >= 0.5
+            )
 
             # plot the original results by Alex Stasik to make a comparison
 
-            if plot_results == '_figureresults':
+            if plot_results == "_figureresults":
                 res = get_figure_limits(cat_name, pdf_type)
                 res_sens = res[pval_mask]
                 res_no_sens = res[np.invert(pval_mask)]
 
                 for arr, marker, label in zip(
-                        [res_sens, res_no_sens],
-                        ['d', 'x'],
-                        ['sensitivity', 'limit']
+                    [res_sens, res_no_sens], ["d", "x"], ["sensitivity", "limit"]
                 ):
-                    ax.errorbar(arr['t'], arr['E'], xerr=arr['t'] * 0.05, yerr=arr['E'] * 0.1,
-                                uplims=True, ls='', markersize=1, capsize=0.5, color=patch.lines[0].get_c(), alpha=0.5)
-                    ax.plot(arr['t'], arr['E'] - arr['E'] * 0.1, marker=marker, color=patch.lines[0].get_c(),
-                            label=cat_name + ' Stasik ' + label, ls='', alpha=0.5)
+                    ax.errorbar(
+                        arr["t"],
+                        arr["E"],
+                        xerr=arr["t"] * 0.05,
+                        yerr=arr["E"] * 0.1,
+                        uplims=True,
+                        ls="",
+                        markersize=1,
+                        capsize=0.5,
+                        color=patch.lines[0].get_c(),
+                        alpha=0.5,
+                    )
+                    ax.plot(
+                        arr["t"],
+                        arr["E"] - arr["E"] * 0.1,
+                        marker=marker,
+                        color=patch.lines[0].get_c(),
+                        label=cat_name + " Stasik " + label,
+                        ls="",
+                        alpha=0.5,
+                    )
 
-            if plot_results == '_tableresults':
-                cat_key = cat_name if not 'p' in cat_name else 'IIP'
-                ekey = 'Fit' if 'fit' or 'Fit' in mh_name else 'Fix'
+            if plot_results == "_tableresults":
+                cat_key = cat_name if not "p" in cat_name else "IIP"
+                ekey = "Fit" if "fit" or "Fit" in mh_name else "Fix"
                 ekey += " Energy (erg)"
-                ax.axhline(limits[cat_key][ekey].value,
-                           ls='--', color=patch.lines[0].get_c(), label=cat_name + ' previous limit')
+                ax.axhline(
+                    limits[cat_key][ekey].value,
+                    ls="--",
+                    color=patch.lines[0].get_c(),
+                    label=cat_name + " previous limit",
+                )
 
-        ax.set_ylabel('$E^{\\nu}_{tot}$ [erg]')
-        ax.set_xlabel('t$_{\mathrm{decay}}$  [y]')
-        ax.set_xscale('log')
-        ax.set_yscale('log')
+        ax.set_ylabel("$E^{\\nu}_{tot}$ [erg]")
+        ax.set_xlabel("t$_{\mathrm{decay}}$  [y]")
+        ax.set_xscale("log")
+        ax.set_yscale("log")
         ax.legend()
 
         plt.grid()
-        plt.title(f'Stacked sensitivity for $\gamma = {gamma}$')
+        plt.title(f"Stacked sensitivity for $\gamma = {gamma}$")
         plt.tight_layout()
 
-        plt.savefig(plot_output_dir(raw + f'stacked_sensitivity_gamma{gamma}_{mh_name}{plot_results}.pdf'))
+        plt.savefig(
+            plot_output_dir(
+                raw + f"stacked_sensitivity_gamma{gamma}_{mh_name}{plot_results}.pdf"
+            )
+        )
 
     end = time.time()
 
-    logging.info('ran in {:.4f} seconds'.format(end - start))
+    logging.info("ran in {:.4f} seconds".format(end - start))
