@@ -1,7 +1,10 @@
 import numpy as np
 from flarestack.data.icecube.ps_tracks.ps_v002_p01 import ps_v002_p01
-from flarestack.analyses.ccsn.stasik_2017.shared_ccsn import sn_cats, sn_catalogue_name, \
-    sn_time_pdfs
+from flarestack.analyses.ccsn.stasik_2017.shared_ccsn import (
+    sn_cats,
+    sn_catalogue_name,
+    sn_time_pdfs,
+)
 from flarestack.core.unblinding import create_unblinder
 from flarestack.utils.custom_dataset import custom_dataset
 
@@ -34,11 +37,10 @@ for cat in sn_cats:
         unblind_dict = {
             "name": name,
             "mh_name": "fit_weights",
-            "dataset": custom_dataset(ps_v002_p01, catalogue,
-                                       llh_time),
+            "dataset": custom_dataset(ps_v002_p01, catalogue, llh_time),
             "catalogue": cat_path,
             "llh_dict": unblind_llh,
-            "background_ts": bkg_ts
+            "background_ts": bkg_ts,
         }
 
         ub = create_unblinder(unblind_dict, mock_unblind=False)
