@@ -14,7 +14,7 @@ source_maps = {
     "ccsn": ["CCSN", "sn", "supernova", "core_collapse_supernova"],
     "grb": ["GRB", "gamma_ray_burst"],
     "fbot": ["FBOT", "fast_blue_optical_transient"],
-    "frb": ["FRB", "fast_radio_bursts"]
+    "frb": ["FRB", "fast_radio_bursts"],
 }
 
 sources = {
@@ -23,11 +23,18 @@ sources = {
     "ccsn": get_ccsn_rate,
     "grb": get_grb_rate,
     "fbot": get_fbot_rate,
-    "frb": get_frb_rate
+    "frb": get_frb_rate,
 }
 
 
-def get_rate(source_name, evolution_name=None, rate_name=None, fraction=1.0, with_range=False, **kwargs):
+def get_rate(
+    source_name,
+    evolution_name=None,
+    rate_name=None,
+    fraction=1.0,
+    with_range=False,
+    **kwargs,
+):
     """Get rate of astrophysical object, as a function of redshift
 
     :param source_name: Name of source class to use
@@ -49,25 +56,30 @@ def get_rate(source_name, evolution_name=None, rate_name=None, fraction=1.0, wit
         if new is not None:
             source_name = new
         else:
-            raise Exception(f"Source class '{source_name}' not recognised. "
-                            f"The following source evolutions are available: {sources.keys()}")
+            raise Exception(
+                f"Source class '{source_name}' not recognised. "
+                f"The following source evolutions are available: {sources.keys()}"
+            )
 
     logger.info(f"Loading source class '{source_name}'")
 
     if fraction != 1.0:
-        logger.info(f"Assuming a modified rate that is {100.*fraction:.2f}% of that total.")
+        logger.info(
+            f"Assuming a modified rate that is {100.*fraction:.2f}% of that total."
+        )
 
     f = sources[source_name](
         evolution_name=evolution_name,
         rate_name=rate_name,
         with_range=with_range,
-        **kwargs
+        **kwargs,
     )
 
     if with_range:
-        return lambda z: f[0](z) * fraction,\
-               lambda z: f[1](z) * fraction,\
-               lambda z: f[2](z) * fraction
+        return (
+            lambda z: f[0](z) * fraction,
+            lambda z: f[1](z) * fraction,
+            lambda z: f[2](z) * fraction,
+        )
     else:
         return lambda z: f(z) * fraction
-
