@@ -2,20 +2,28 @@ import logging
 from astropy.cosmology import Planck15 as cosmo
 from astropy import units as u
 import numpy as np
-from flarestack.cosmo.rates.sfr_rates import get_local_sfr_rate, get_sfr_evolution, sfr_evolutions, local_sfr_rates
+from flarestack.cosmo.rates.sfr_rates import (
+    get_local_sfr_rate,
+    get_sfr_evolution,
+    sfr_evolutions,
+    local_sfr_rates,
+)
 
 # Taken from https://arxiv.org/pdf/1509.06574.pdf
 
 sn_subclass_rates = {
-    "li_11": ({
-        "IIn": 0.064,
-        "IIP": 0.52,
-        "IIL": 0.073,
-        "II": 0.064 + 0.52 + 0.073,
-        "Ib": 0.069,
-        "Ic": 0.176,
-        "Ibc": 0.069 + 0.176,
-    }, "https://arxiv.org/abs/1006.4612")
+    "li_11": (
+        {
+            "IIn": 0.064,
+            "IIP": 0.52,
+            "IIL": 0.073,
+            "II": 0.064 + 0.52 + 0.073,
+            "Ib": 0.069,
+            "Ic": 0.176,
+            "Ibc": 0.069 + 0.176,
+        },
+        "https://arxiv.org/abs/1006.4612",
+    )
 }
 
 
@@ -31,11 +39,15 @@ def get_sn_subfraction(sn_subclass_fractions_name=None):
         sn_subclass_fractions_name = "li_11"
 
     if sn_subclass_fractions_name not in sn_subclass_rates.keys():
-        raise Exception(f"Subclass name '{sn_subclass_fractions_name}' not recognised. "
-                        f"The following kcc values are available: {sn_subclass_rates.keys()}")
+        raise Exception(
+            f"Subclass name '{sn_subclass_fractions_name}' not recognised. "
+            f"The following kcc values are available: {sn_subclass_rates.keys()}"
+        )
     else:
         sn_rates, ref = sn_subclass_rates[sn_subclass_fractions_name]
-        logging.info(f"Loaded SN subclass fractions '{sn_subclass_fractions_name}' ({ref})")
+        logging.info(
+            f"Loaded SN subclass fractions '{sn_subclass_fractions_name}' ({ref})"
+        )
 
     return sn_rates
 
@@ -63,27 +75,26 @@ def get_sn_fraction(sn_subclass=None, sn_subclass_fractions_name=None):
         sn_types = get_sn_subfraction(sn_subclass_fractions_name)
 
         if sn_subclass in sn_types.keys():
-            logging.info(f"Subclass '{sn_subclass}' is equal to "
-                         f"{100.*sn_types[sn_subclass]:.2f}% of the CCSN rate.")
+            logging.info(
+                f"Subclass '{sn_subclass}' is equal to "
+                f"{100.*sn_types[sn_subclass]:.2f}% of the CCSN rate."
+            )
             return sn_types[sn_subclass]
         else:
-            raise Exception(f"Supernova type '{sn_subclass}' not recognised. "
-                            f"The following types are available: {sn_types.keys()}")
+            raise Exception(
+                f"Supernova type '{sn_subclass}' not recognised. "
+                f"The following types are available: {sn_types.keys()}"
+            )
 
 
 kcc_rates = {
-    "madau_14": (
-        0.0068 / u.solMass,
-        None,
-        None,
-        "http://arxiv.org/abs/1403.0007v3"
-    ),
+    "madau_14": (0.0068 / u.solMass, None, None, "http://arxiv.org/abs/1403.0007v3"),
     "strolger_15": (
-        0.0091 * cosmo.h ** 2. / cosmo.h ** 3 / u.solMass,
-        (0.0091 - 0.0017) * cosmo.h ** 2. / cosmo.h ** 3 / u.solMass,
-        (0.0091 + 0.0017) * cosmo.h ** 2. / cosmo.h ** 3 / u.solMass,
-        "https://arxiv.org/abs/1509.06574"
-    )
+        0.0091 * cosmo.h**2.0 / cosmo.h**3 / u.solMass,
+        (0.0091 - 0.0017) * cosmo.h**2.0 / cosmo.h**3 / u.solMass,
+        (0.0091 + 0.0017) * cosmo.h**2.0 / cosmo.h**3 / u.solMass,
+        "https://arxiv.org/abs/1509.06574",
+    ),
 }
 
 
@@ -96,12 +107,16 @@ def get_kcc_rate(kcc_name=None, with_range=False):
     """
 
     if kcc_name is None:
-        logging.info("No specified kcc (sn per unit star formation). Assuming default kcc.")
+        logging.info(
+            "No specified kcc (sn per unit star formation). Assuming default kcc."
+        )
         kcc_name = "madau_14"
 
     if kcc_name not in kcc_rates.keys():
-        raise Exception(f"kcc name '{kcc_name}' not recognised. "
-                        f"The following kcc values are available: {kcc_rates.keys()}")
+        raise Exception(
+            f"kcc name '{kcc_name}' not recognised. "
+            f"The following kcc values are available: {kcc_rates.keys()}"
+        )
     else:
         kcc, lower_lim, upper_lim, ref = kcc_rates[kcc_name]
         logging.info(f"Loaded kcc '{kcc_name}' ({ref})")
@@ -109,8 +124,10 @@ def get_kcc_rate(kcc_name=None, with_range=False):
     if with_range:
 
         if lower_lim is None:
-            logging.warning(f"No one sigma kcc range found for kcc '{kcc_name}'. "
-                            f"No error on this value will be propagated. ")
+            logging.warning(
+                f"No one sigma kcc range found for kcc '{kcc_name}'. "
+                f"No error on this value will be propagated. "
+            )
 
         return kcc, lower_lim, upper_lim
 
@@ -118,7 +135,9 @@ def get_kcc_rate(kcc_name=None, with_range=False):
         return kcc
 
 
-def get_local_ccsn_rate(rate_name=None, kcc_name=None, sn_subclass=None, with_range=False):
+def get_local_ccsn_rate(
+    rate_name=None, kcc_name=None, sn_subclass=None, with_range=False
+):
     """Returns a local rate of core-collapse supernovae (CCSNe).
 
     :param rate_name: Name of local Star Formation Rate (sfr) to be used
@@ -140,14 +159,23 @@ def get_local_ccsn_rate(rate_name=None, kcc_name=None, sn_subclass=None, with_ra
 
     if with_range:
 
-        return sfr_rate * kcc[0] * subclass_fraction, \
-               sfr_rate * kcc[1] * subclass_fraction, \
-               sfr_rate * kcc[2] * subclass_fraction
+        return (
+            sfr_rate * kcc[0] * subclass_fraction,
+            sfr_rate * kcc[1] * subclass_fraction,
+            sfr_rate * kcc[2] * subclass_fraction,
+        )
     else:
         return sfr_rate * kcc * subclass_fraction
 
 
-def get_ccsn_rate(evolution_name=None, rate_name=None, kcc_name=None, sn_subclass=None, with_range=False, **kwargs):
+def get_ccsn_rate(
+    evolution_name=None,
+    rate_name=None,
+    kcc_name=None,
+    sn_subclass=None,
+    with_range=False,
+    **kwargs,
+):
     """Returns a local rate of core-collapse supernovae (CCSNe) as a function of redshift.
 
     :param evolution_name: Name of Star Formation evolution to use
@@ -163,12 +191,14 @@ def get_ccsn_rate(evolution_name=None, rate_name=None, kcc_name=None, sn_subclas
         rate_name=rate_name,
         kcc_name=kcc_name,
         sn_subclass=sn_subclass,
-        with_range=with_range
+        with_range=with_range,
     )
 
     if with_range:
-        return lambda z: local_rate[0] * normed_evolution(z), \
-               lambda z: local_rate[1] * normed_evolution(z), \
-               lambda z: local_rate[2] * normed_evolution(z)
+        return (
+            lambda z: local_rate[0] * normed_evolution(z),
+            lambda z: local_rate[1] * normed_evolution(z),
+            lambda z: local_rate[2] * normed_evolution(z),
+        )
     else:
         return lambda z: local_rate * normed_evolution(z)
