@@ -10,9 +10,8 @@ from flarestack.data.public.icecube import PublicICSeason
 
 logger = logging.getLogger(__name__)
 
+
 class BackgroundFluxModel:
-
-
     def __init__(self, flux_norm, bkg_time_pdf_dict):
         self.flux_norm = flux_to_k(flux_norm)
         self.bkg_time_pdf_dict = bkg_time_pdf_dict
@@ -32,8 +31,8 @@ class BackgroundFluxModel:
     def build_time_pdf_dict(self):
         return self.bkg_time_pdf_dict
 
-class IdealBackgroundFluxModel(BackgroundFluxModel):
 
+class IdealBackgroundFluxModel(BackgroundFluxModel):
     def __init__(self, flux_norm, bkg_time_pdf_dict):
         BackgroundFluxModel.__init__(self, flux_norm, bkg_time_pdf_dict)
         self.atmo = self.atmo_flux()
@@ -43,8 +42,8 @@ class IdealBackgroundFluxModel(BackgroundFluxModel):
         bkg_e_pdf_dict = {
             "energy_pdf_name": "power_law",
             "gamma": 3.7,
-            "e_min_gev": 100.,
-            "e_max_gev": 10.**7
+            "e_min_gev": 100.0,
+            "e_max_gev": 10.0**7,
         }
         return EnergyPDF.create(bkg_e_pdf_dict)
 
@@ -56,36 +55,51 @@ class IdealBackgroundFluxModel(BackgroundFluxModel):
 
 
 class PotemkinSeason(SimSeason):
-
-    def __init__(self, season_name, sample_name, pseudo_mc_path,
-                 event_dtype, load_effective_area, load_angular_resolution,
-                 bkg_flux_model,
-                 energy_proxy_map, sin_dec_bins, log_e_bins, a_eff_path, **kwargs):
+    def __init__(
+        self,
+        season_name,
+        sample_name,
+        pseudo_mc_path,
+        event_dtype,
+        load_effective_area,
+        load_angular_resolution,
+        bkg_flux_model,
+        energy_proxy_map,
+        sin_dec_bins,
+        log_e_bins,
+        a_eff_path,
+        **kwargs,
+    ):
 
         self.log_e_bins = log_e_bins
         self.sin_dec_bins = sin_dec_bins
         self.a_eff_path = a_eff_path
 
         SimSeason.__init__(
-            self, season_name, sample_name, pseudo_mc_path,
-            event_dtype, load_effective_area,
-            load_angular_resolution, bkg_flux_model,
-            energy_proxy_map, **kwargs
+            self,
+            season_name,
+            sample_name,
+            pseudo_mc_path,
+            event_dtype,
+            load_effective_area,
+            load_angular_resolution,
+            bkg_flux_model,
+            energy_proxy_map,
+            **kwargs,
         )
 
     def generate_sim_data(self, fluence):
         logger.info("Simulating events:")
-        sim_events = np.empty((0,),
-                              dtype=self.event_dtype)
+        sim_events = np.empty((0,), dtype=self.event_dtype)
 
         for i, lower_sin_dec in enumerate(self.sin_dec_bins[:-1]):
             upper_sin_dec = self.sin_dec_bins[i + 1]
-            new_events = self.simulate_dec_range(
-                fluence,lower_sin_dec, upper_sin_dec)
+            new_events = self.simulate_dec_range(fluence, lower_sin_dec, upper_sin_dec)
 
-            logger.info("Simulated {0} events between sin(dec)={1} and "
-                  "sin(dec)={2}".format(
-                len(new_events), lower_sin_dec, upper_sin_dec))
+            logger.info(
+                "Simulated {0} events between sin(dec)={1} and "
+                "sin(dec)={2}".format(len(new_events), lower_sin_dec, upper_sin_dec)
+            )
 
             # Joins the new events to the signal events
             sim_events = np.concatenate((sim_events, new_events))
@@ -100,13 +114,14 @@ class PotemkinSeason(SimSeason):
         mean_sin_dec = 0.5 * (lower_sin_dec + upper_sin_dec)
 
         solid_angle = 2 * np.pi * (upper_sin_dec - lower_sin_dec)
-        sim_fluence = fluence * solid_angle # GeV^-1 cm^-2
+        sim_fluence = fluence * solid_angle  # GeV^-1 cm^-2
 
         effective_area_f = self.load_effective_area()
 
         def source_eff_area(e):
             return effective_area_f(
-                np.log10(e), mean_sin_dec) * self.bkg_flux_model.flux_model_f(e, mean_sin_dec)
+                np.log10(e), mean_sin_dec
+            ) * self.bkg_flux_model.flux_model_f(e, mean_sin_dec)
 
         lower, upper = self.bkg_flux_model.flux_range()
 
@@ -133,8 +148,7 @@ class PotemkinSeason(SimSeason):
         new_events["dec"] = np.arcsin(new_events["sinDec"])
         new_events["time"] = self.get_time_pdf().simulate_times([], n_sim)
 
-        fluence_ints, log_e_range = \
-            EnergyPDF.piecewise_integrate(
+        fluence_ints, log_e_range = EnergyPDF.piecewise_integrate(
             source_eff_area, lower, upper
         )
 
@@ -143,17 +157,19 @@ class PotemkinSeason(SimSeason):
         fluence_ints = np.array(fluence_ints)
         fluence_ints /= np.sum(fluence_ints)
 
-        fluence_cumulative = [np.sum(fluence_ints[:i])
-                              for i, _ in enumerate(fluence_ints)]
+        fluence_cumulative = [
+            np.sum(fluence_ints[:i]) for i, _ in enumerate(fluence_ints)
+        ]
 
-        fluence_cumulative = [0.] + fluence_cumulative + [1.]
+        fluence_cumulative = [0.0] + fluence_cumulative + [1.0]
 
         log_e_range = list(log_e_range) + [log_e_range[-1]]
 
         sim_true_e = interp1d(fluence_cumulative, log_e_range)
 
         true_e_vals = np.array(
-            [10.**sim_true_e(random.random()) for _ in range(n_sim)])
+            [10.0 ** sim_true_e(random.random()) for _ in range(n_sim)]
+        )
 
         new_events["logE"] = self.energy_proxy_map(true_e_vals)
 
@@ -175,6 +191,7 @@ class PotemkinSeason(SimSeason):
             a_eff_path=self.a_eff_path,
         )
 
+
 potemkin_dataset = SimDataset()
 
 for (name, season) in icecube_ps_3_year.get_seasons().items():
@@ -188,14 +205,15 @@ for (name, season) in icecube_ps_3_year.get_seasons().items():
             energy_proxy_map = ideal_energy_proxy
             sim_name = "default"
 
-        if np.logical_and(energy_proxy_map != ideal_energy_proxy,
-                          sim_name is None):
-            raise ValueError("Non-default energy proxy mapping was used, "
-                             "but no unique sim_name was provided. Please "
-                             "provide a unique 'sim_name' to describe this "
-                             "simulation.")
+        if np.logical_and(energy_proxy_map != ideal_energy_proxy, sim_name is None):
+            raise ValueError(
+                "Non-default energy proxy mapping was used, "
+                "but no unique sim_name was provided. Please "
+                "provide a unique 'sim_name' to describe this "
+                "simulation."
+            )
 
-        sin_dec_bins = season.sin_dec_bins[season.sin_dec_bins > 0.]
+        sin_dec_bins = season.sin_dec_bins[season.sin_dec_bins > 0.0]
 
         sim_season = PotemkinSeason(
             season_name=name,
@@ -209,7 +227,7 @@ for (name, season) in icecube_ps_3_year.get_seasons().items():
             sin_dec_bins=sin_dec_bins,
             log_e_bins=season.log_e_bins,
             a_eff_path=season.a_eff_path,
-            **kwargs
+            **kwargs,
         )
         return sim_season
 
