@@ -5,6 +5,7 @@ from flarestack.shared import min_angular_err
 
 logger = logging.getLogger(__name__)
 
+
 def data_loader(data_path, floor=True, cut_fields=True):
     """Helper function to load data for a given season/set of season.
     Adds sinDec field if this is not available, and combines multiple years
@@ -17,19 +18,18 @@ def data_loader(data_path, floor=True, cut_fields=True):
     """
 
     if isinstance(data_path, list):
-        dataset = np.concatenate(
-            tuple([np.load(x) for x in data_path]))
+        dataset = np.concatenate(tuple([np.load(x) for x in data_path]))
     else:
         dataset = np.load(data_path, allow_pickle=True)
 
     if "sinDec" not in dataset.dtype.names:
 
-        new_dtype = np.dtype([("sinDec", np.float)])
+        new_dtype = np.dtype([("sinDec", float)])
 
         sinDec = np.array(np.sin(dataset["dec"]), dtype=new_dtype)
 
         dataset = append_fields(
-            dataset, 'sinDec', sinDec, usemask=False, dtypes=[np.float]
+            dataset, "sinDec", sinDec, usemask=False, dtypes=[float]
         )
 
     # Check if 'run' or 'Run'
@@ -46,12 +46,14 @@ def data_loader(data_path, floor=True, cut_fields=True):
         if "angErr" in dataset.dtype.names:
             dataset = rename_fields(dataset, {"angErr": "sigma"})
         else:
-            raise Exception("No recognised Angular Error field found in "
-                            "dataset. (Searched for 'sigma' and 'angErr')")
+            raise Exception(
+                "No recognised Angular Error field found in "
+                "dataset. (Searched for 'sigma' and 'angErr')"
+            )
 
     if "raw_sigma" not in dataset.dtype.names:
         dataset = append_fields(
-            dataset, 'raw_sigma', dataset["sigma"], usemask=False, dtypes=[np.float]
+            dataset, "raw_sigma", dataset["sigma"], usemask=False, dtypes=[float]
         )
 
     # Apply a minimum angular error "floor"
@@ -60,8 +62,19 @@ def data_loader(data_path, floor=True, cut_fields=True):
 
     if cut_fields:
 
-        allowed_fields = ['time', 'ra', 'dec', 'sigma', 'logE', 'trueE',
-                          'trueRa', 'trueDec', 'ow', 'sinDec', 'raw_sigma']
+        allowed_fields = [
+            "time",
+            "ra",
+            "dec",
+            "sigma",
+            "logE",
+            "trueE",
+            "trueRa",
+            "trueDec",
+            "ow",
+            "sinDec",
+            "raw_sigma",
+        ]
 
         mask = [x for x in dataset.dtype.names if x in allowed_fields]
 
@@ -73,12 +86,12 @@ def data_loader(data_path, floor=True, cut_fields=True):
 def grl_loader(season):
 
     if isinstance(season.grl_path, list):
-        grl = np.sort(np.array(np.concatenate(
-            [np.load(x) for x in season.grl_path])),
-            order="run")
+        grl = np.sort(
+            np.array(np.concatenate([np.load(x) for x in season.grl_path])), order="run"
+        )
     else:
         grl = np.load(season.grl_path)
-        
+
     # Check if bad runs are found in GRL
     try:
         if np.sum(~grl["good_i3"]) == 0:
@@ -89,17 +102,21 @@ def grl_loader(season):
             logger.error(grl[~grl["good_i3"]])
             raise Exception("Runs marked as 'bad' are found in Good Run List")
     except ValueError:
-        logger.warning("No field called 'good_i3' found in GoodRunList. "
-                        "Cannot check if all runs in GoodRunList are actually good.")
+        logger.warning(
+            "No field called 'good_i3' found in GoodRunList. "
+            "Cannot check if all runs in GoodRunList are actually good."
+        )
 
     if "length" not in grl.dtype.names:
 
         if "livetime" in grl.dtype.names:
             grl = rename_fields(grl, {"livetime": "length"})
         else:
-            raise Exception("No recognised Livetime field found in "
-                            "GoodRunList. (Searched for 'livetime' and "
-                            "'length')")
+            raise Exception(
+                "No recognised Livetime field found in "
+                "GoodRunList. (Searched for 'livetime' and "
+                "'length')"
+            )
 
     # Check if there are events in runs not found in GRL
 
@@ -107,12 +124,14 @@ def grl_loader(season):
     if "run" in exp_data.dtype.names:
         bad_runs = [x for x in set(exp_data["run"]) if x not in grl["run"]]
         if len(bad_runs) > 0:
-            raise Exception("Trying to use GoodRunList, but events in data have "
-                            "runs that are not included on this GoodRunList. \n"
-                            "Please check to make sure both the GoodRunList, "
-                            "and the event selection, are correct. \n" +
-                            "The following runs are affected: \n" +
-                            str(bad_runs))
+            raise Exception(
+                "Trying to use GoodRunList, but events in data have "
+                "runs that are not included on this GoodRunList. \n"
+                "Please check to make sure both the GoodRunList, "
+                "and the event selection, are correct. \n"
+                + "The following runs are affected: \n"
+                + str(bad_runs)
+            )
 
     # Sometimes, inexplicable, the runs come in random orders rather than
     # ascending order. This deals with that.
@@ -126,9 +145,11 @@ def grl_loader(season):
 
 def verify_grl_with_data(seasons):
 
-    logger.info("Verifying that, for each dataset, all events are in runs that \n" \
-          "are on the GRL, and not outside the period marked as good in the " \
-          "GRL.")
+    logger.info(
+        "Verifying that, for each dataset, all events are in runs that \n"
+        "are on the GRL, and not outside the period marked as good in the "
+        "GRL."
+    )
 
     for name, season in seasons.items():
         print(name)
@@ -140,28 +161,33 @@ def verify_grl_with_data(seasons):
         # Check if there are events in runs that are on the GRL, but outside the
         # period marked as good in the GRL
 
-        n_overflow = 0.
+        n_overflow = 0.0
         affected_runs = []
 
         for run in grl:
             data = exp_data[exp_data["run"] == run["run"]]
-            mask = np.logical_and(data["time"] >= run["start"],
-                                  data["time"] <= run["stop"])
+            mask = np.logical_and(
+                data["time"] >= run["start"], data["time"] <= run["stop"]
+            )
 
             if np.sum(~mask) > 0:
                 n_overflow += np.sum(~mask)
                 affected_runs.append(run["run"])
 
-        if n_overflow > 0.:
+        if n_overflow > 0.0:
 
-            fraction = float(n_overflow)/float(len(exp_data))
+            fraction = float(n_overflow) / float(len(exp_data))
 
-            raise Exception("Found events in data set " + season["Name"] +
-                            " which are in runs from the GoodRunList, \n but "
-                            "the times of these runs lie outside the periods "
-                            "marked as good. \n In total, " + str(fraction) +
-                            " of events are affected. \n The following runs are"
-                            " affected: \n" + str(affected_runs))
+            raise Exception(
+                "Found events in data set "
+                + season["Name"]
+                + " which are in runs from the GoodRunList, \n but "
+                "the times of these runs lie outside the periods "
+                "marked as good. \n In total, "
+                + str(fraction)
+                + " of events are affected. \n The following runs are"
+                " affected: \n" + str(affected_runs)
+            )
 
         else:
             print("Passed!")
